import { FailbotBackend } from '../failbot-backend';
declare type Headers = Record<string, string>;
export interface HTTPBackendOptions {
    app?: string;
    fetchFn?: typeof fetch;
    haystackURL: string;
    headers?: Headers;
}
/**
 * A backend that reports errors via HTTP.
 *
 * By default, this reporter will use the global `fetch`, but one can be
 * provided when a global one is unavailable.
 *
 * ```ts
 * const backend = new HTTPBackend({
 *   fetchFn: fetchPolyfill,
 *   haystackURL: process.env.HAYSTACK_URL
 * })
 * ```
 */
export declare class HTTPBackend implements FailbotBackend {
    haystackURL: string;
    app: string | undefined;
    headers: Headers;
    fetchFn: typeof fetch | undefined;
    constructor(opts: HTTPBackendOptions);
    report(error: Error, metadata?: {
        [key: string]: unknown;
    }): Promise<Response>;
    get fetch(): typeof fetch;
}
export {};
//# sourceMappingURL=http.d.ts.map